
# zalo_sign_in

Pub.dev : https://pub.dev/packages/zalo_sign_in

## Setup

* Register your applicaton at Zalo developer page : https://developers.zalo.me/
* Add plugin to your ```pubspec.yaml``` file:

```yaml
dependencies:
  zalo_sign_in: ^0.0.1+3
```

### 1. Android set up:
* Step 1: Define your Zalo application id in ```strings.xml``` file
```xml
<string name="appID">[your_id]</string>
```
* Step 2: Update ```AndroidManifest.xml``` file:
```xml
<meta-data
  android:name="com.zing.zalo.zalosdk.appID"
  android:value="@string/appID" />
```
* Step 3: Create application class, which will extend from ```FlutterApplication``` and set ZaloSDK as below:
```Kotlin
class App : FlutterApplication() {

    override fun onCreate() {
        super.onCreate()
        ZaloSDKApplication.wrap(this)
    }
}
```
* Step 4: Register application class in ```AndroidManifest.xml``` file:
```xml
<application
  android:name=".App"
  ....
```
Get more detail at: https://developers.zalo.me/docs/sdk/android-sdk-8

### 2. iOS set up:
* Step 1: Add ```CFBundleURLTypes``` to ```Info.plist``` file:
```xml
<key>CFBundleURLTypes</key>
	<array>
		<dict>
			<key>CFBundleTypeRole</key>
			<string>Editor</string>
			<key>CFBundleURLName</key>
			<string>zalo</string>
			<key>CFBundleURLSchemes</key>
			<array>
				<string>zalo-[your_id]</string>
			</array>
		</dict>
</array>
```
* Step 2: Init ZaloSDK at ```AppDelegate.swift``` file:
```swift
override func application(
        _ application: UIApplication,
        didFinishLaunchingWithOptions launchOptions: [UIApplication.LaunchOptionsKey: Any]?
    ) -> Bool {

        GeneratedPluginRegistrant.register(with: self)

        ZaloSDK.sharedInstance().initialize(withAppId: "[your_id]")

        return super.application(application, didFinishLaunchingWithOptions: launchOptions)
    }
```
* Step 3: Define call back url for Zalo
```swift
 override  func application(_ application: UIApplication, open url: URL, sourceApplication: String?, annotation: Any) -> Bool {
        print(url)
        return ZDKApplicationDelegate.sharedInstance().application(application, open: url, sourceApplication: sourceApplication, annotation: annotation)    }
```
Get more detail at: https://developers.zalo.me/docs/sdk/ios-sdk/tich-hop/xcode-post-460

## How to user plugin?

* Step 1: Import :
```Dart
import 'package:zalo_sign_in/zalo_sign_in.dart';
import 'package:zalo_sign_in/zalo_sign_in_result.dart';
```
* Step 2: Use ```ZaloSignIn``` to
```Dart
ZaloSignInResult zaloSignInResult =
    await ZaloSignIn().signIn();
```
### Detail of ```ZaloSignInResult```:
```Dart
class ZaloSignInResult {
  bool isSuccess;
  int errorCode;
  String message;
  String oauthCode;
}
```
